+++
title = "2020-04-19"
description = """
  Test the case where the title contains only the date, making it look
  like a Hugo TOML date field.
  """
tags = ["title"]
draft = false
+++

`ox-hugo` Issue #[350](https://github.com/kaushalmodi/ox-hugo/issues/350)
